@@ -91,6 +91,10 @@ void
 katze_item_set_icon               (KatzeItem*      item,
                                    const gchar*    icon);
 
+GdkPixbuf*
+katze_item_get_pixbuf             (KatzeItem*      item,
+                                   GtkWidget*      widget);
+
 GtkWidget*
 katze_item_get_image              (KatzeItem*      item);
 
