@@ -80,7 +80,8 @@ midori_startup_get_type (void) G_GNUC_CONST;
 
 typedef enum
 {
-    MIDORI_ENCODING_CHINESE,
+    MIDORI_ENCODING_CHINESE /* Traditional */,
+    MIDORI_ENCODING_CHINESE_SIMPLIFIED,
     MIDORI_ENCODING_JAPANESE,
     MIDORI_ENCODING_KOREAN,
     MIDORI_ENCODING_RUSSIAN,
