@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2008-2010 Christian Dywan <christian@twotoasts.de>
+ Copyright (C) 2008-2012 Christian Dywan <christian@twotoasts.de>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -97,7 +97,7 @@ midori_findbar_find_key_press_event_cb (MidoriFindbar* findbar,
     else if (event->keyval == GDK_KEY_Return
           && (event->state & GDK_SHIFT_MASK))
     {
-        midori_findbar_find (findbar, FALSE);
+        midori_findbar_find_text (findbar, NULL, FALSE);
         return TRUE;
     }
 
@@ -141,16 +141,43 @@ midori_findbar_find_text (MidoriFindbar* findbar,
     if (!(view = midori_browser_get_current_tab (browser)))
         return;
 
+    if (text == NULL)
+        text = gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
+
     case_sensitive = midori_findbar_case_sensitive (findbar);
     midori_view_search_text (MIDORI_VIEW (view), text, case_sensitive, forward);
 }
 
+/**
+ * midori_findbar_get_text:
+ * @findbar: #MidoriFindbar
+ *
+ * Returns: the text typed in the entry
+ *
+ * Since: 0.4.5
+ **/
+const gchar*
+midori_findbar_get_text (MidoriFindbar* findbar)
+{
+    g_return_val_if_fail (MIDORI_IS_FINDBAR (findbar), NULL);
+
+    return gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
+}
+
+/**
+ * midori_findbar_find:
+ * @findbar: #MidoriFindbar
+ * @forward: %TRUE to search forward
+ *
+ * Advance to the next match.
+ *
+ * Deprecated: 0.4.5: Use midori_findbar_find_text() instead.
+ **/
 void
 midori_findbar_find (MidoriFindbar* findbar,
                      gboolean       forward)
 {
-    const gchar* text = gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
-    midori_findbar_find_text (findbar, text, forward);
+    midori_findbar_find_text (findbar, NULL, forward);
 }
 
 void
@@ -179,14 +206,14 @@ static void
 midori_findbar_next_activate_cb (GtkWidget*     entry,
                                  MidoriFindbar* findbar)
 {
-    midori_findbar_find (findbar, TRUE);
+    midori_findbar_find_text (findbar, NULL, TRUE);
 }
 
 static void
 midori_findbar_previous_clicked_cb (GtkWidget*     entry,
                                     MidoriFindbar* findbar)
 {
-    midori_findbar_find (findbar, FALSE);
+    midori_findbar_find_text (findbar, NULL, FALSE);
 }
 
 static void
@@ -253,6 +280,7 @@ midori_findbar_init (MidoriFindbar* findbar)
     #endif
     gtk_toolbar_set_icon_size (GTK_TOOLBAR (findbar), GTK_ICON_SIZE_MENU);
     gtk_toolbar_set_style (GTK_TOOLBAR (findbar), GTK_TOOLBAR_BOTH_HORIZ);
+    gtk_toolbar_set_show_arrow (GTK_TOOLBAR (findbar), FALSE);
     g_signal_connect (findbar, "key-press-event",
         G_CALLBACK (midori_findbar_find_key_press_event_cb), NULL);
 
@@ -336,7 +364,7 @@ void
 midori_findbar_search_text (MidoriFindbar* findbar,
                             GtkWidget*     view,
                             gboolean       found,
-                            gchar*         typing)
+                            const gchar*   typing)
 {
     const gchar* text;
     gboolean case_sensitive;
